@@ -32,7 +32,7 @@ def main(config_path):
         if metric["enabled"]:
             for doc in metric_data:
                 doc["_plugin"] =  metric["name"]
-                doc["_documentType"]  = metric["name"]+"Success"
+                doc["_documentType"]  = metric["document_type"]
                 doc["_tag_Name"] = config.get("tags",{}).get("Name","")
                 doc["_tag_appName"] = config.get("tags",{}).get("appName","")
                 doc["_tag_projectName"] = config.get("tags",{}).get("projectName","")
